@@ -1,7 +1,7 @@
 /* File addpix.c
  * June 21, 2006
- * By Doug Mink, Harvard-Smithsonian Center for Astrophysics
- * Send bug reports to dmink@cfa.harvard.edu
+ * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
+ * Send bug reports to jmink@cfa.harvard.edu
 
    Copyright (C) 2006 
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
@@ -34,7 +34,7 @@
 static void usage();
 static int newimage = 0;
 static int verbose = 0;		/* verbose flag */
-static char *RevMsg = "ADDPIX WCSTools 3.8.4, 1 September 2011, Doug Mink (dmink@cfa.harvard.edu)";
+static char *RevMsg = "ADDPIX WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 static void AddPix();
 static int version = 0;		/* If 1, print only program name and version */
 
