@@ -1,7 +1,7 @@
 /* File bincat.c
  * January 10, 2007
- * By Doug Mink, Harvard-Smithsonian Center for Astrophysics
- * Send bug reports to dmink@cfa.harvard.edu
+ * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
+ * Send bug reports to jmink@cfa.harvard.edu
 
    Copyright (C) 2003-2007
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
@@ -48,7 +48,7 @@ extern void setrefpix();
 extern void setcdelt();
 extern struct WorldCoor *GetFITSWCS();
 
-static char *RevMsg = "BINCAT WCSTools 3.8.4, 1 September 2011, Doug Mink (dmink@cfa.harvard.edu)";
+static char *RevMsg = "BINCAT WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 static int verbose = 0;		/* verbose flag */
 static int debug = 0;		/* debugging flag */
 static int bitpix = 0;	/* number of bits per pixel (FITS code, 0=no image) */
