@@ -1,8 +1,8 @@
 /* File delwcs.c
  * June 21, 2006
- * By Doug Mink, after University of Iowa code
+ * By Jessica Mink, after University of Iowa code
  * (Harvard-Smithsonian Center for Astrophysics)
- * Send bug reports to dmink@cfa.harvard.edu
+ * Send bug reports to jmink@cfa.harvard.edu
 
    Copyright (C) 2006 
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
@@ -38,7 +38,7 @@ extern int DelWCSFITS ();
 static int verbose = 0;		/* Verbose/debugging flag */
 static int newimage = 0;	/* New image flag */
 static int readimage = 1;	/* Read and write image as well as header */
-static char *RevMsg = "DELWCS WCSTools 3.8.4, 1 September 2011, Doug Mink (dmink@cfa.harvard.edu)";
+static char *RevMsg = "DELWCS WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 static int version = 0;		/* If 1, print only program name and version */
 
 int
