@@ -1,7 +1,7 @@
 /* File getcol.c
  * April 18, 2011
- * By Doug Mink, Harvard-Smithsonian Center for Astrophysics
- * Send bug reports to dmink@cfa.harvard.edu
+ * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
+ * Send bug reports to jmink@cfa.harvard.edu
 
    Copyright (C) 1999-2011
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
@@ -37,7 +37,7 @@
 #define MAXFILES	2000
 #define MAXLINES	100000
 
-static char *RevMsg = "GETCOL WCSTools 3.8.4, 1 September 2011, Doug Mink SAO";
+static char *RevMsg = "GETCOL WCSTools 3.8.5, 12 April 2012, Jessica Mink SAO";
 
 static void usage();
 static int ListFile();
