@@ -1,7 +1,7 @@
 /* File getpix.c
  * September 21, 2010
- * By Doug Mink, Harvard-Smithsonian Center for Astrophysics)
- * Send bug reports to dmink@cfa.harvard.edu
+ * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics)
+ * Send bug reports to jmink@cfa.harvard.edu
 
    Copyright (C) 1996-2010
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
@@ -36,7 +36,7 @@ static void usage();
 static void PrintPix();
 static void procpix();
 
-static char *RevMsg = "GETPIX WCSTools 3.8.4, 1 September 2011, Doug Mink SAO";
+static char *RevMsg = "GETPIX WCSTools 3.8.5, 12 April 2012, Jessica Mink SAO";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int version = 0;		/* If 1, print only program name and version */
