@@ -1,7 +1,7 @@
 /* File imextract.c
  * November 12, 2009
- * By Doug Mink, Harvard-Smithsonian Center for Astrophysics
- * Send bug reports to dmink@cfa.harvard.edu
+ * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
+ * Send bug reports to jmink@cfa.harvard.edu
 
    Copyright (C) 1999-2009 
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
@@ -37,7 +37,7 @@
 static void usage();
 static int ExtractImage();
 
-static char *RevMsg = "IMEXTRACT WCSTools 3.8.4, 1 September 2011, Doug Mink (dmink@cfa.harvard.edu)";
+static char *RevMsg = "IMEXTRACT WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose flag */
 static int krename = 0;
