@@ -1,7 +1,7 @@
 /* File imfill.c
  * January 10, 2007
- * By Doug Mink, Harvard-Smithsonian Center for Astrophysics
- * Send bug reports to dmink@cfa.harvard.edu
+ * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
+ * Send bug reports to jmink@cfa.harvard.edu
 
    Copyright (C) 2006-2007
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
@@ -63,7 +63,7 @@ static char *badheader;		/* FITS bad pixel header */
 static double minpixval = -9999.0;	/* Minimum good pixel value */
 static double maxpixval = -9999.0;	/* Maximum good pixel value */
 
-static char *RevMsg = "IMFILL WCSTools 3.8.4, 1 September 2011, Doug Mink (dmink@cfa.harvard.edu)";
+static char *RevMsg = "IMFILL WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 
 int
 main (ac, av)
