@@ -1,7 +1,7 @@
 /* File imsize.c
  * March 24, 2009
- * By Doug Mink, Harvard-Smithsonian Center for Astrophysics
- * Send bug reports to dmink@cfa.harvard.edu
+ * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
+ * Send bug reports to jmink@cfa.harvard.edu
 
    Copyright (C) 1996-2009
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
@@ -44,7 +44,7 @@ static char coorsys[8];
 static double size = 0.0;
 static double frac = 0.0;
 
-static char *RevMsg = "IMSIZE WCSTools 3.8.4, 1 September 2011, Doug Mink (dmink@cfa.harvard.edu)";
+static char *RevMsg = "IMSIZE WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int dss = 0;		/* Flag to drop extra stuff for DSS */
