@@ -1,8 +1,8 @@
 /* File imwcs.c
  * April 6, 2007
- * By Doug Mink, after Elwood Downey
+ * By Jessica Mink, after Elwood Downey
  * (Harvard-Smithsonian Center for Astrophysics)
- * Send bug reports to dmink@cfa.harvard.edu
+ * Send bug reports to jmink@cfa.harvard.edu
 
    Copyright (C) 1996-2007
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
@@ -40,7 +40,7 @@ static int maxnfile = MAXFILES;
 static void PrintUsage();
 static void FitWCS();
 
-static char *RevMsg = "WCSTools 3.8.4, 1 September 2011, Doug Mink (dmink@cfa.harvard.edu)";
+static char *RevMsg = "WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int writeheader = 0;	/* write header fields; else read-only */
