@@ -1,7 +1,7 @@
 /* File keyhead.c
  * August 19, 2009
- * By Doug Mink Harvard-Smithsonian Center for Astrophysics)
- * Send bug reports to dmink@cfa.harvard.edu
+ * By Jessica Mink Harvard-Smithsonian Center for Astrophysics)
+ * Send bug reports to jmink@cfa.harvard.edu
 
    Copyright (C) 1997-2009
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
@@ -50,7 +50,7 @@ static int logfile = 0;
 static int nproc = 0;
 static int first_file = 1;
 
-static char *RevMsg = "KEYHEAD WCSTools 3.8.4, 1 September 2011, Doug Mink (dmink@cfa.harvard.edu)";
+static char *RevMsg = "KEYHEAD WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 
 int
 main (ac, av)
