@@ -1,7 +1,7 @@
 /* File remap.c
  * October 15, 2010
- * By Doug Mink, Harvard-Smithsonian Center for Astrophysics
- * Send bug reports to dmink@cfa.harvard.edu
+ * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
+ * Send bug reports to jmink@cfa.harvard.edu
 
    Copyright (C) 1999-2010
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
@@ -50,7 +50,7 @@ static char *outname0 = "remap.fits";
 static char *outname;
 static char *wcsproj;           /* WCS projection name */
 
-static char *RevMsg = "REMAP WCSTools 3.8.4, 1 September 2011, Doug Mink (dmink@cfa.harvard.edu)";
+static char *RevMsg = "REMAP WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 static int nfiles = 0;
 static int fitsout = 1;
 static double secpix = 0;
