@@ -1,7 +1,7 @@
 /* File sethead.c
  * September 1, 2011
- * By Doug Mink Harvard-Smithsonian Center for Astrophysics)
- * Send bug reports to dmink@cfa.harvard.edu
+ * By Jessica Mink Harvard-Smithsonian Center for Astrophysics)
+ * Send bug reports to jmink@cfa.harvard.edu
 
    Copyright (C) 1996-2011
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
@@ -66,7 +66,7 @@ static int addwcs = 0;
 static int errflag = 0;		/* Error return from program */
 static char *rootdir=NULL;	/* Root directory for input files */
 
-static char *RevMsg = "SETHEAD WCSTools 3.8.4, 1 September 2011, Doug Mink (dmink@cfa.harvard.edu)";
+static char *RevMsg = "SETHEAD WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 
 int
 main (ac, av)
