@@ -1,6 +1,6 @@
 /*** simpos.c - search object by its name from command line arguments
  *** October 3, 2007
- *** By Doug Mink, sort of after IPAC byname.c
+ *** By Jessica Mink, sort of after IPAC byname.c
  */
 
 #include <stdlib.h>
@@ -12,7 +12,7 @@
 
 extern int   ned_errno;
 static void PrintUsage();
-static char *RevMsg = "SIMPOS 3.8.4, 1 September 2011, Doug Mink SAO";
+static char *RevMsg = "SIMPOS 3.8.5, 12 April 2012, Jessica Mink SAO";
 
 int
 main (ac, av)
