@@ -1,7 +1,7 @@
 /* File sky2xy.c
  * September 25, 2009
- * By Doug Mink, Harvard-Smithsonian Center for Astrophysics
- * Send bug reports to dmink@cfa.harvard.edu
+ * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
+ * Send bug reports to jmink@cfa.harvard.edu
 
    Copyright (C) 1996-2009
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
@@ -39,7 +39,7 @@ extern struct WorldCoor *GetWCSFITS ();	/* Read WCS from FITS or IRAF file */
 extern char *GetFITShead();
 static int version = 0;		/* If 1, print only program name and version */
 
-static char *RevMsg = "SKY2XY WCSTools 3.8.4, 1 September 2011, Doug Mink (dmink@cfa.harvard.edu)";
+static char *RevMsg = "SKY2XY WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 
 int
 main (ac, av)
