@@ -1,7 +1,7 @@
 /* File xy2sky.c
  * September 22, 2010
- * By Doug Mink, Harvard-Smithsonian Center for Astrophysics
- * Send bug reports to dmink@cfa.harvard.edu
+ * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
+ * Send bug reports to jmink@cfa.harvard.edu
 
    Copyright (C) 1996-2010
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
@@ -49,7 +49,7 @@ static int printhead = 0;
 static char printonly = 'n';
 static int version = 0;		/* If 1, print only program name and version */
 
-static char *RevMsg = "XY2SKY WCSTools 3.8.4, 1 September 2011, Doug Mink (dmink@cfa.harvard.edu)";
+static char *RevMsg = "XY2SKY WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 
 int
 main (ac, av)
